@@ -1,5 +1,13 @@
 package Net::WebSocket::Endpoint::Server;
 
+use strict;
+use warnings;
+
+use parent qw(
+    Net::WebSocket::Endpoint
+    Net::WebSocket::Masker::Server
+);
+
 =encoding utf-8
 
 =head1 NAME
@@ -24,30 +32,18 @@ Net::WebSocket::Endpoint::Server
         },
     );
 
+    my $msg_to_send = $ept->create_message('text', 'Hello!');
+
     if ( _we_timed_out_waiting_for_read_readiness() ) {
         $ept->check_heartbeat();
     }
     else {
 
-        #Only necessary for non-blocking I/O;
-        #it’s meaningless in blocking I/O.
-        #See below for an alternative pattern for use with POE, etc.
-        if ( $ept->get_write_queue_size() ) {
-            $ept->flush_write_queue();
-        }
-
         #This should only be called when reading won’t produce an error.
         #For example, in non-blocking I/O you’ll need a select() in front
         #of this. (Blocking I/O can just call it and wait!)
         $ept->get_next_message();
 
-        #INSTEAD OF flush_write_queue(), you might want to send the write
-        #queue off to a multiplexing framework like POE, for which this
-        #would be useful:
-        while ( my $frame = $ept->shift_write_queue() ) {
-            #… do something with $frame->to_bytes() -- probably send it
-        }
-
         #Check for this at the end of each cycle.
         _custom_logic_to_finish_up() if $ept->is_closed();
     }
@@ -95,8 +91,18 @@ If you want to avoid buffering a large message, you can do this:
 
 =head2 I<OBJ>->get_next_message()
 
-The “workhorse” method. It returns a data message if one is available
-and is the next frame; otherwise, it returns undef.
+The “workhorse” method. It returns one of the following:
+
+=over
+
+=item * a data message if one is available
+
+=item * empty string if the Parser’s C<get_next_frame()> indicated
+end-of-file without an exception
+
+=item * otherwise, undef
+
+=back
 
 This method also handles control frames that arrive before or among
 message frames:
@@ -108,15 +114,29 @@ See below for more information.
 
 =item * ping: Send the appropriate pong frame.
 
-=item * pong: Set the internal ping counter to zero. If the pong is
-unrecognized (i.e., we’ve not sent the payload in a ping), then we send
-a PROTOCOL_ERROR close frame.
+=item * pong: As per the protocol specification.
 
 =back
 
 This method may not be called after a close frame has been sent (i.e.,
 if the C<is_closed()> method returns true).
 
+=head2 I<OBJ>->create_message( FRAME_TYPE, PAYLOAD )
+
+Creates an unfragmented message with the given PAYLOAD.
+
+FRAME_TYPE can be either C<text> or C<binary> (for Net::WebSocket’s
+default frame classes) or full package names (e.g., to use a custom
+frame class).
+
+This is a convenience method that takes care of mask creation and module
+loading for you.
+
+See L<Net::WebSocket::PMCE::deflate::Data> for similar functionality
+to create a compressed message.
+
+=cut
+
 =head2 I<OBJ>->check_heartbeat()
 
 Ordinarily, sends a distinct ping frame to the remote server
@@ -144,6 +164,19 @@ DEPRECATED: Returns 1 or 0 to indicate whether we have sent a close frame.
 Note that C<sent_close_frame()> provides a more useful variant of the
 same functionality; there is no good reason to use this method anymore.
 
+=head2 I<OBJ>->do_not_die_on_close()
+
+Ordinarily, receipt of a close frame prompts an exception after the
+response close frame is sent. This is, arguably, a suboptimal design
+choice since receipt of a close frame is a perfectly normal thing to happen;
+i.e., it’s not “exception-al”. If you want to check for close yourself
+instead, you can do so by calling this method.
+
+=head2 I<OBJ>->die_on_close()
+
+The inverse of C<do_not_die_on_close()>: restores
+the default behavior when a close frame is received.
+
 =head1 WHEN A CLOSE FRAME IS RECEIVED
 
 C<get_next_message()> will automatically send a close frame in response
@@ -176,12 +209,4 @@ see the documentation for L<Net::WebSocket::Parser>.
 
 =cut
 
-use strict;
-use warnings;
-
-use parent qw(
-    Net::WebSocket::Endpoint
-    Net::WebSocket::Masker::Server
-);
-
 1;
